# -*- coding: utf-8 -*-

"""
The external package integrations module (:mod:`class_resolver.contrib`) contains
pre-built class resolvers for common class hierarchies and
pre-built function resolvers for common groups of functions
in external packages like :mod:`torch`, :mod:`numpy`, and :mod:`optuna`.
"""  # noqa:D205,D400
